#!/bin/sh
#
# -----------------------------------------------------------------------------
#
# ZenBuild script for synaptics
# ===========================
# Author:	Thibaud GUERIN <guth@ploposor.com>
# URL:		http://web.telia.com/~u89404340/touchpad/files/synaptics-0.14.6.tar.bz2

soft='synaptics'
softversion='0.14.6'
packageversion='50.3'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/${soft}-${softversion}.tar.bz2"
src="$buildir/${soft}-${softversion}"
package="${soft}-${softversion}-${arch}-${packageversion}"
dest="$buildir/${package}"


cd $buildir
rm -rf $src


#
# Extract the tar ball, patch and modify
#
echo "Extracting the program tarball..."
tar -xf $srcpkg

rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest
#chown -R root:root .
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXFLAGS="-O2 -march=i486 -mtune=$cpu"

cd $src

patch -p1 < $buildir/synaptics-patch.diff
mkdir -p $dest/usr/bin
mkdir -p $dest/usr/man/man1
mkdir -p $dest/usr/man/man5

echo "Building ..."
#cat Makefile |sed 's/INSTALLED_X =/INSTALLED_X \?=/g' > Makefile.patched
#mv Makefile Makefile.unpatched
#mv Makefile.patched Makefile

make
DESTDIR=$dest PREFIX=/usr make install
cd ..


chown -R root.root $dest

# No icon
# No .desktop

( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)
( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)


## --- DOCUMENTATION ---
echo "Building Doc"
rm -rf $dest/usr/share/doc
mkdir -p $dest/usr/doc/$soft-$softversion

# Unpack the separate documentation tarball
cd $src
cp -a NEWS TODO INSTALL INSTALL.DE INSTALL.FR LICENSE README README.alps docs $dest/usr/doc/$soft-$softversion
cd ..
chown -R root.root $dest/usr/doc/$soft-$softversion/*
chmod -R a-ws $dest/usr/doc/$soft-$softversion/*

# Compress the man pages
gzip -9f $dest/usr/man/*/*


# --- PACKAGE DESCRIPTION ---
mkdir -p $dest/install

cat <<EOF > $dest/install/slack-desc
#       |-----handy-ruler------------------------------------------------------|
$soft: Synaptics TouchPad driver for Xorg
$soft:
$soft: This is a driver for the Synaptics TouchPad for XOrg/XFree86 4.x.
$soft: It provides scrolling, more button events, ...
$soft: 
$soft: 
$soft: 
$soft: 
$soft: 
$soft: 
$soft: 
EOF

cat <<EOF > $dest/install/doinst.sh
if [ -e /var/log/packages/xorg-7.3* ] && [ -e /etc/X11/xorg.conf ]; then
  ( cd /etc/X11/
    mv xorg.conf xorg.conf-synaptics
    sed 's/AlwaysCore/SendCoreEvents/gI' xorg.conf-synaptics > xorg.conf
  )
fi
EOF

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion
cp $buildir/synaptics-patch.diff $dest/usr/src/$soft-$softversion

# --- OWNERSHIP, RIGHTS ---

chmod -R o-w $dest


# --- BUILDING ---

echo "Build package"
cd $dest
/sbin/makepkg -l y -c n $dest.tgz
md5sum $dest.tgz > $dest.md5
echo -n "xorg" > $dest.dep
